# Axial

#### Interactive Visualizations for High Dimensional Genomics Data

[Homepage](http://alexlenail.me/Axial/)

Axial is a data visualization library.

Unlike other data visualization libraries, Axial returns interactive html instead of png or svg.
Many of the figure configuration parameters can be dynamically set in the browser.
This makes it easier to explore one's dataset with low friction.

Axial was built with high dimensional genomics data in mind, but can readily be adapted to other data types which can suitably be visualized by one of the visualization types Axial provides.

Axial plots can be generated via python (see the [Python Docs](http://alexlenail.me/Axial/html/index.html)). Support for R is coming.

### Python

- Installation

    ```
    pip install axial
    ```
- [Documentation](http://alexlenail.me/Axial/html/index.html)

### R

In progress.


### JavaScript (development)

See the [javascript docs]().
